from setuptools import setup

setup(name='korora',
      version='0.0.1',
      description='korora backup',
      author='Mario Verbelen',
      author_email='mario@verbelen.org',
      license='MIT',
      packages=['korora']
      )
